@@ -25,6 +25,7 @@
 #include <random>
 #include <stdexcept>
 #include <utility>
+#include <vector>
 
 /* general literanger headers */
 #include "utility_draw.h"
@@ -369,6 +370,16 @@ void Tree<ImplT>::best_decrease_by_value_largeq(
 
     ImplT & tree_impl = *static_cast<ImplT *>(this);
 
+    prepare_candidate_loop_via_index(split_key, node_key, data, sample_keys);
+
+  /* Break if pure or empty node. */
+    size_t test_n_candidate = 0;
+    for (const size_t & n : node_n_by_candidate) {
+        test_n_candidate += n > 0;
+        if (test_n_candidate == 2) break;
+    }
+    if (test_n_candidate != 2) return;
+
     const size_t n_sample_node = get_n_sample_node(node_key);
     const size_t n_candidate_value =
         data->get_n_unique_predictor_value(split_key);
@@ -386,13 +397,6 @@ void Tree<ImplT>::best_decrease_by_value_largeq(
         if (best_value == x1) best_value = x0;
     };
 
-    prepare_candidate_loop_via_index(split_key, node_key, data, sample_keys);
-
-  /* Break if pure or empty node. */
-    size_t real_n_candidate = 0;
-    for (const size_t & n : node_n_by_candidate) real_n_candidate += n > 0;
-    if (real_n_candidate < 2) return;
-
     tree_impl.best_decrease_by_real_value(
         split_key, n_sample_node, n_candidate_value,
         best_decrease, best_split_key, update_best_value
